=========================
VCS Utilities for Tendril
=========================

.. image:: https://img.shields.io/travis/chintal/tendril-utils-vcs.svg
        :target: https://travis-ci.org/chintal/tendril-utils-vcs

.. image:: https://img.shields.io/pypi/v/tendril-utils-vcs.svg
        :target: https://pypi.python.org/pypi/tendril-utils-vcs

* License: AGPLv3
* Documentation: http://tendril-utils-vcs.readthedocs.org


VCS utilities for Tendril.
